Your message dated Fri, 24 Oct 2008 16:05:57 +0000
with message-id <[EMAIL PROTECTED]>
and subject line Bug#498663: fixed in reportbug 3.99.0
has caused the Debian Bug report #498663,
regarding pseudo-packages canonical on bugs.d.o now
to be marked as done.

This means that you claim that the problem has been dealt with.
If this is not the case it is now your responsibility to reopen the
Bug report if necessary, and/or fix the problem forthwith.

(NB: If you are a system administrator and have no idea what this
message is talking about, this may indicate a serious mail system
misconfiguration somewhere. Please contact [EMAIL PROTECTED]
immediately.)


-- 
498663: http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=498663
Debian Bug Tracking System
Contact [EMAIL PROTECTED] with problems
--- Begin Message ---
Package: reportbug
Version: 3.45
Tags: patch

Hi,

The bugs.debian.org copy of the pseudo-packages' list is the canonical one
now (cf. #449097), so please apply the attached patch.

Mind, I think that this shouldn't be restricted to the source package's
'make checks'. Use reportbug instances should test the timestamp on their
shipped copy of the pseudo-package list, and if it's older than one year,
they should (offer to the user to) update it from the canonical location.
It's a really small and simple file.

Please fix this. TIA.

-- 
     2. That which causes joy or happiness.
--- reportbug-3.45/checks/compare_pseudo-pkgs_lists.py.orig	2008-09-12 01:43:20.000000000 +0200
+++ reportbug-3.45/checks/compare_pseudo-pkgs_lists.py	2008-09-12 01:48:09.000000000 +0200
@@ -3,7 +3,7 @@
 # License: Public domain
 #
 # Python script to compare pseudo-packages listed in reportbug
 # agaists the official list on ftp-master
 
 import sys, os
 sys.path = ['.'] + sys.path
@@ -12,27 +12,27 @@
 
 import urllib, re
 
-# separete a sequence of "char not spaces", from at least one space (ftp-master uses tabs), from anything after tabs
+# separete a sequence of "char not spaces", from at least one space (canonical copy uses tabs), from anything after tabs
 # we group the first and the latter, so we get the pseudo-packages name and description
 dictparse = re.compile(r'([^\s]+)\s+(.+)',re.IGNORECASE)
 
-ftpmaster_list = {}
-pseudo = urllib.urlopen('http://ftp-master.debian.org/pseudo-packages.description')
+bdo_list = {}
+pseudo = urllib.urlopen('http://bugs.debian.org/pseudopackages/pseudo-packages.description')
 for l in pseudo:
     m = dictparse.search(l)
-    ftpmaster_list[m.group(1)] = m.group(2)
+    bdo_list[m.group(1)] = m.group(2)
 
 bts_keys=debianbts.debother.keys();
 
-diff_rb_ftp = set(bts_keys)-set(ftpmaster_list)
-diff_ftp_rb = set(ftpmaster_list)-set(bts_keys)
+diff_rb_bdo = set(bts_keys)-set(bdo_list)
+diff_bdo_rb = set(bdo_list)-set(bts_keys)
 
-print "pseudo-pkgs in reportbug not in ftpmaster list:", diff_rb_ftp
+print "pseudo-pkgs in reportbug not in bugs.debian.org list:", diff_rb_bdo
 
-for pkg in diff_rb_ftp:
+for pkg in diff_rb_bdo:
     print "   ", pkg,": ", debianbts.debother[pkg]
 
-print "pseudo-pkgs in ftpmaster list not in reprotbug:", diff_ftp_rb
+print "pseudo-pkgs in bugs.debian.org list not in reportbug:", diff_bdo_rb
 
-for pkg in diff_ftp_rb:
-    print "   ", pkg,": ", ftpmaster_list[pkg]
+for pkg in diff_bdo_rb:
+    print "   ", pkg,": ", bdo_list[pkg]

--- End Message ---
--- Begin Message ---
Source: reportbug
Source-Version: 3.99.0

We believe that the bug you reported is fixed in the latest version of
reportbug, which is due to be installed in the Debian FTP archive:

python-reportbug_3.99.0_all.deb
  to pool/main/r/reportbug/python-reportbug_3.99.0_all.deb
reportbug_3.99.0.dsc
  to pool/main/r/reportbug/reportbug_3.99.0.dsc
reportbug_3.99.0.tar.gz
  to pool/main/r/reportbug/reportbug_3.99.0.tar.gz
reportbug_3.99.0_all.deb
  to pool/main/r/reportbug/reportbug_3.99.0_all.deb



A summary of the changes between this version and the previous one is
attached.

Thank you for reporting the bug, which will now be closed.  If you
have further comments please address them to [EMAIL PROTECTED],
and the maintainer will reopen the bug report if appropriate.

Debian distribution maintenance software
pp.
Sandro Tosi <[EMAIL PROTECTED]> (supplier of updated reportbug package)

(This message was generated automatically at their request; if you
believe that there is a problem with it please contact the archive
administrators by mailing [EMAIL PROTECTED])


-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA1

Format: 1.8
Date: Thu, 23 Oct 2008 16:04:28 +0200
Source: reportbug
Binary: reportbug python-reportbug
Architecture: source all
Version: 3.99.0
Distribution: experimental
Urgency: low
Maintainer: Reportbug Maintainers <[EMAIL PROTECTED]>
Changed-By: Sandro Tosi <[EMAIL PROTECTED]>
Description: 
 python-reportbug - Python modules for interacting with bug tracking systems
 reportbug  - reports bugs in the Debian distribution
Closes: 497024 498663
Changes: 
 reportbug (3.99.0) experimental; urgency=low
 .
   [ Chris Lawrence ]
   * Split off python-reportbug into a separate package.
 .
   [ Sandro Tosi ]
   * Split off python-reportbug into a separate package
     - bin/reportbug
       + fixed VERSION and COPYRIGHT import
       + hacked the way to identify working ui
       + remove module name from some methods call, since we import selectively
         some methods only
     - setup.py
       + added reportbug.ui to packages to install UI files
     - bin/querybts
       + hacked the way to identify working ui
     - reportbug/ui/{text.py,urwid.py}
       + replaced relative imports with absolute ones
       + removed reportbug.utils import to avoid circular import (and because
         it's not needed)
     - reportbug/ui/{newt.py,text.py,urwid.py}
       + renamed to <file>_ui.py because from <file>.py you cannot import <file>
         (urwid UI had this problem)
     - reportbug/{submit.py,utils.py}, bin/{querybts,reportbug}
       + fixed for ui file rename
     - reportbug/{utils.py,ui/__init__.py}
       + moved UIs list to ui.__init__, where it belongs; Closes: #497024
     - bin/{querybts,reportbug}
       - changed for new UIs list location
   * reportbug/debianbts.py
     - added buildd.emdebian.org and debian-i18n pseudo-packages
   * man/{querybts.1,reportbug.1,reportbug.conf.5}
     - added UI information; thanks to Luca Bruno's patch
   * checks/compare_pseudo-pkgs_lists.py
     - updated location of canonical pseudo-packages list from ftpmaster to
       bugs.d.o; thanks to Josip Rodin for the patch; Closes: #498663
   * doc/README.*, debian/docs
     - moved README.* files under doc/ dir
   * TODO
     - updated
   * debian/control
     - updated my email address
   * debian/source.lintian-overrides
     - added to override the warning about po4a wrong build-dep (we need it
       because it's used in clean debian/rules target)
 .
   * Added GTK+ UI
     [ Luca Bruno ]
     - reportbug/ui/gtk2_ui.py
       + GTK+ interface
 .
     [ Sandro Tosi ]
     - debian/control
       + added python-gtk2 to suggests
     - debian/copyright
       + added gtk2 ui copyright
     - debian/{control.greportbug,greportbug.menu}
       + removed since no more needed
     - debian/menu
       + added entry for GTK+ ui
Checksums-Sha1: 
 86bc7b68267bed0b0cdc48ec3d734eaff90f9200 1224 reportbug_3.99.0.dsc
 90fba813b1a0724f74bb8090811b7b64851d56dd 186612 reportbug_3.99.0.tar.gz
 69394ff9922d7e46b94d5947e4b43115c8c16165 113540 reportbug_3.99.0_all.deb
 444596eb62ed47e786e2db76193b6b5bcb52d66b 108460 python-reportbug_3.99.0_all.deb
Checksums-Sha256: 
 d426aa3fe8c7e625c393860d8e307fa312953cac6c00845aaa46b02bf965310f 1224 
reportbug_3.99.0.dsc
 cf2653eaf94d88708afb1fd6d34ec6260de3019a6b440a0dd7d36bf50e7094ef 186612 
reportbug_3.99.0.tar.gz
 ba264b537236465003a2f7bf7ef02d1e82803907093d3ebbdfcaf116035810be 113540 
reportbug_3.99.0_all.deb
 e9baa582c308d1232c9d6de9eb44693f61d89c0e322b95b4c7cfd8cc98d12fcf 108460 
python-reportbug_3.99.0_all.deb
Files: 
 a2058101324f1826ae5d636bfd2d5b6b 1224 utils standard reportbug_3.99.0.dsc
 18abf78a47b6c9516f8897f7b628bfda 186612 utils standard reportbug_3.99.0.tar.gz
 6b5d2603ae5d374e68b812c88bcb9b39 113540 utils standard reportbug_3.99.0_all.deb
 320275cc0873380af3cebb75e6af94e5 108460 python standard 
python-reportbug_3.99.0_all.deb

-----BEGIN PGP SIGNATURE-----
Version: GnuPG v1.4.9 (GNU/Linux)

iEYEARECAAYFAkkAilwACgkQAukwV0RN2VBjMwCfW2kF/wyYk+0mVKrtubMYb66e
A+gAoJU0VYkr4kpSHXkQOOeng/MYYNk8
=Eb/Q
-----END PGP SIGNATURE-----



--- End Message ---
@@ -3,7 +3,7 @@
 #
 # Python script to compare pseudo-packages listed in reportbug
-# agaists the official list on ftp-master
+# agaists the official list on bugs.debian.org
 
 import sys, os

Reply via email to